﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace EFOracleProvider
{
    enum OracleType
    {
                // Summary:
        //     An Oracle BFILE data type that contains a reference to binary data with a
        //     maximum size of 4 gigabytes that is stored in an external file. Use the OracleClient
        //     System.Data.OracleClient.OracleBFile data type with the System.Data.OracleClient.OracleParameter.Value
        //     property.
        BFile = 1,
        //
        // Summary:
        //     An Oracle BLOB data type that contains binary data with a maximum size of
        //     4 gigabytes. Use the OracleClient System.Data.OracleClient.OracleLob data
        //     type in System.Data.OracleClient.OracleParameter.Value.
        Blob = 2,
        //
        // Summary:
        //     An Oracle CHAR data type that contains a fixed-length character string with
        //     a maximum size of 2,000 bytes. Use the .NET Framework System.String or OracleClient
        //     System.Data.OracleClient.OracleString data type in System.Data.OracleClient.OracleParameter.Value.
        Char = 3,
        //
        // Summary:
        //     An Oracle CLOB data type that contains character data, based on the default
        //     character set on the server, with a maximum size of 4 gigabytes. Use the
        //     OracleClient System.Data.OracleClient.OracleLob data type in System.Data.OracleClient.OracleParameter.Value.
        Clob = 4,
        //
        // Summary:
        //     An Oracle REF CURSOR. The System.Data.OracleClient.OracleDataReader object
        //     is not available.
        Cursor = 5,
        //
        // Summary:
        //     An Oracle DATE data type that contains a fixed-length representation of a
        //     date and time, ranging from January 1, 4712 B.C. to December 31, A.D. 4712,
        //     with the default format dd-mmm-yy. For A.D. dates, DATE maps to System.DateTime.
        //     To bind B.C. dates, use a String parameter and the Oracle TO_DATE or TO_CHAR
        //     conversion functions for input and output parameters respectively. Use the
        //     .NET Framework System.DateTime or OracleClient System.Data.OracleClient.OracleDateTime
        //     data type in System.Data.OracleClient.OracleParameter.Value.
        DateTime = 6,
        //
        // Summary:
        //     An Oracle INTERVAL DAY TO SECOND data type (Oracle 9i or later) that contains
        //     an interval of time in days, hours, minutes, and seconds, and has a fixed
        //     size of 11 bytes. Use the .NET Framework System.TimeSpan or OracleClient
        //     System.Data.OracleClient.OracleTimeSpan data type in System.Data.OracleClient.OracleParameter.Value.
        IntervalDayToSecond = 7,
        //
        // Summary:
        //     An Oracle INTERVAL YEAR TO MONTH data type (Oracle 9i or later) that contains
        //     an interval of time in years and months, and has a fixed size of 5 bytes.
        //     Use the .NET Framework System.Int32 or OracleClient System.Data.OracleClient.OracleMonthSpan
        //     data type in System.Data.OracleClient.OracleParameter.Value.
        IntervalYearToMonth = 8,
        //
        // Summary:
        //     An Oracle LONGRAW data type that contains variable-length binary data with
        //     a maximum size of 2 gigabytes. Use the .NET Framework Byte[] or OracleClient
        //     System.Data.OracleClient.OracleBinary data type in System.Data.OracleClient.OracleParameter.Value.
        LongRaw = 9,
        //
        // Summary:
        //     An Oracle LONG data type that contains a variable-length character string
        //     with a maximum size of 2 gigabytes. Use the .NET Framework System.String
        //     or OracleClient System.Data.OracleClient.OracleString data type in System.Data.OracleClient.OracleParameter.Value.
        LongVarChar = 10,
        //
        // Summary:
        //     An Oracle NCHAR data type that contains fixed-length character string to
        //     be stored in the national character set of the database, with a maximum size
        //     of 2,000 bytes (not characters) when stored in the database. The size of
        //     the value depends on the national character set of the database. See your
        //     Oracle documentation for more information. Use the .NET Framework System.String
        //     or OracleClient System.Data.OracleClient.OracleString data type in System.Data.OracleClient.OracleParameter.Value.
        NChar = 11,
        //
        // Summary:
        //     An Oracle NCLOB data type that contains character data to be stored in the
        //     national character set of the database, with a maximum size of 4 gigabytes
        //     (not characters) when stored in the database. The size of the value depends
        //     on the national character set of the database. See your Oracle documentation
        //     for more information. Use the .NET Framework System.String or OracleClient
        //     System.Data.OracleClient.OracleString data type in System.Data.OracleClient.OracleParameter.Value.
        NClob = 12,
        //
        // Summary:
        //     An Oracle NUMBER data type that contains variable-length numeric data with
        //     a maximum precision and scale of 38. This maps to System.Decimal. To bind
        //     an Oracle NUMBER that exceeds what System.Decimal.MaxValue can contain, either
        //     use an System.Data.OracleClient.OracleNumber data type, or use a String parameter
        //     and the Oracle TO_NUMBER or TO_CHAR conversion functions for input and output
        //     parameters respectively. Use the .NET Framework System.Decimal or OracleClient
        //     System.Data.OracleClient.OracleNumber data type in System.Data.OracleClient.OracleParameter.Value.
        Number = 13,
        //
        // Summary:
        //     An Oracle NVARCHAR2 data type that contains a variable-length character string
        //     stored in the national character set of the database, with a maximum size
        //     of 4,000 bytes (not characters) when stored in the database. The size of
        //     the value depends on the national character set of the database. See your
        //     Oracle documentation for more information. Use the .NET Framework System.String
        //     or OracleClient System.Data.OracleClient.OracleString data type in System.Data.OracleClient.OracleParameter.Value.
        NVarChar = 14,
        //
        // Summary:
        //     An Oracle RAW data type that contains variable-length binary data with a
        //     maximum size of 2,000 bytes. Use the .NET Framework Byte[] or OracleClient
        //     System.Data.OracleClient.OracleBinary data type in System.Data.OracleClient.OracleParameter.Value.
        Raw = 15,
        //
        // Summary:
        //     The base64 string representation of an Oracle ROWID data type. Use the .NET
        //     Framework System.String or OracleClient System.Data.OracleClient.OracleString
        //     data type in System.Data.OracleClient.OracleParameter.Value.
        RowId = 16,
        //
        // Summary:
        //     An Oracle TIMESTAMP (Oracle 9i or later) that contains date and time (including
        //     seconds), and ranges in size from 7 to 11 bytes. Use the .NET Framework System.DateTime
        //     or OracleClient System.Data.OracleClient.OracleDateTime data type in System.Data.OracleClient.OracleParameter.Value.
        Timestamp = 18,
        //
        // Summary:
        //     An Oracle TIMESTAMP WITH LOCAL TIMEZONE (Oracle 9i or later) that contains
        //     date, time, and a reference to the original time zone, and ranges in size
        //     from 7 to 11 bytes. Use the .NET Framework System.DateTime or OracleClient
        //     System.Data.OracleClient.OracleDateTime data type in System.Data.OracleClient.OracleParameter.Value.
        TimestampLocal = 19,
        //
        // Summary:
        //     An Oracle TIMESTAMP WITH TIMEZONE (Oracle 9i or later) that contains date,
        //     time, and a specified time zone, and has a fixed size of 13 bytes. Use the
        //     .NET Framework System.DateTime or OracleClient System.Data.OracleClient.OracleDateTime
        //     data type in System.Data.OracleClient.OracleParameter.Value.
        TimestampWithTZ = 20,
        //
        // Summary:
        //     An Oracle VARCHAR2 data type that contains a variable-length character string
        //     with a maximum size of 4,000 bytes. Use the .NET Framework System.String
        //     or OracleClient System.Data.OracleClient.OracleString data type in System.Data.OracleClient.OracleParameter.Value.
        VarChar = 22,
        //
        // Summary:
        //     An integral type representing unsigned 8-bit integers with values between
        //     0 and 255. This is not a native Oracle data type, but is provided to improve
        //     performance when binding input parameters. Use the .NET Framework System.Byte
        //     data type in System.Data.OracleClient.OracleParameter.Value.
        Byte = 23,
        //
        // Summary:
        //     An integral type representing unsigned 16-bit integers with values between
        //     0 and 65535. This is not a native Oracle data type, but is provided to improve
        //     performance when binding input parameters. For information about conversion
        //     of Oracle numeric values to common language runtime (CLR) data types, see
        //     System.Data.OracleClient.OracleNumber. Use the .NET Framework System.UInt16
        //     or OracleClient System.Data.OracleClient.OracleNumber data type in System.Data.OracleClient.OracleParameter.Value.
        UInt16 = 24,
        //
        // Summary:
        //     An integral type representing unsigned 32-bit integers with values between
        //     0 and 4294967295. This is not a native Oracle data type, but is provided
        //     to improve performance when binding input parameters. For information about
        //     conversion of Oracle numeric values to common language runtime (CLR) data
        //     types, see System.Data.OracleClient.OracleNumber. Use the .NET Framework
        //     System.UInt32 or OracleClient System.Data.OracleClient.OracleNumber data
        //     type in System.Data.OracleClient.OracleParameter.Value.
        UInt32 = 25,
        //
        // Summary:
        //     An integral type representing signed 8 bit integers with values between -128
        //     and 127. This is not a native Oracle data type, but is provided to improve
        //     performance when binding input parameters. Use the .NET Framework System.SByte
        //     data type in System.Data.OracleClient.OracleParameter.Value.
        SByte = 26,
        //
        // Summary:
        //     An integral type representing signed 16-bit integers with values between
        //     -32768 and 32767. This is not a native Oracle data type, but is provided
        //     to improve performance when binding input parameters. For information about
        //     conversion of Oracle numeric values to common language runtime (CLR) data
        //     types, see System.Data.OracleClient.OracleNumber. Use the .NET Framework
        //     System.Int16 or OracleClient System.Data.OracleClient.OracleNumber data type
        //     in System.Data.OracleClient.OracleParameter.Value.
        Int16 = 27,
        //
        // Summary:
        //     An integral type representing signed 32-bit integers with values between
        //     -2147483648 and 2147483647. This is not a native Oracle data type, but is
        //     provided for performance when binding input parameters. For information about
        //     conversion of Oracle numeric values to common language runtime data types,
        //     see System.Data.OracleClient.OracleNumber. Use the .NET Framework System.Int32
        //     or OracleClient System.Data.OracleClient.OracleNumber data type in System.Data.OracleClient.OracleParameter.Value.
        Int32 = 28,
        //
        // Summary:
        //     A single-precision floating-point value. This is not a native Oracle data
        //     type, but is provided to improve performance when binding input parameters.
        //     For information about conversion of Oracle numeric values to common language
        //     runtime data types, see System.Data.OracleClient.OracleNumber. Use the .NET
        //     Framework System.Single or OracleClient System.Data.OracleClient.OracleNumber
        //     data type in System.Data.OracleClient.OracleParameter.Value.
        Float = 29,
        //
        // Summary:
        //     A double-precision floating-point value. This is not a native Oracle data
        //     type, but is provided to improve performance when binding input parameters.
        //     For information about conversion of Oracle numeric values to common language
        //     runtime (CLR) data types, see System.Data.OracleClient.OracleNumber. Use
        //     the .NET Framework System.Double or OracleClient System.Data.OracleClient.OracleNumber
        //     data type in System.Data.OracleClient.OracleParameter.Value.
        Double = 30,
    }
}
